v0.1.0
======

:date: 2024-02-24 (JST)

First release as current name.

Features
--------

* Integration as Sphinx extension
* New bundled roles

  * ``npm`` : For Node.js packages
  * ``pypi`` : For Python packages
